# A packaged PyPi application (Artifactory)
#### Will create a random number between 2, 100 and calculate all Prime numbers that come before it. package and push to a private PyPi registry (Artifactory)

### Functions
#### You must generate a random number (randint) and call `printPrime(number).`
